

![GitHub last commit (branch)](https://img.shields.io/github/last-commit/tdsxtract/tdsxtract/main?style=for-the-badge)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tdsxtract/tdsxtract/test?label=tests&style=for-the-badge)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/tdsxtract/tdsxtract/docs_pages_workflow?label=doc&style=for-the-badge)
![PyPI](https://img.shields.io/pypi/v/tdsxtract?color=b5514c&logo=python&logoColor=white&style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dm/tdsxtract?style=for-the-badge)

# tdsxtract

Tools for extracting permittivity values from Terahertz Time Domain Spectroscopy 
measurements.

See the documentation at [tdsxtract.github.io/tdsxtract](https://tdsxtract.github.io/tdsxtract/).
